package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickMasterActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Stack Voltage")
    public @ActionOutput(name = "voltage", type="int")
           Map<String, Object> brickMasterGetStackVoltage(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickMaster)this.handler.getDevice()).getStackVoltage();
        result.put("voltage", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetStackVoltage(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetStackVoltage();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Stack Current")
    public @ActionOutput(name = "current", type="int")
           Map<String, Object> brickMasterGetStackCurrent(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickMaster)this.handler.getDevice()).getStackCurrent();
        result.put("current", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetStackCurrent(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetStackCurrent();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Extension Type")
    public @ActionOutput(name = "exttype", type="long")
           Map<String, Object> brickMasterGetExtensionType(
            @ActionInput(name = "extension") short extension) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        long value = ((BrickMaster)this.handler.getDevice()).getExtensionType(extension);
        result.put("exttype", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetExtensionType(@Nullable ThingActions actions, short extension) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetExtensionType(extension);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Is Chibi Present")
    public @ActionOutput(name = "present", type="boolean")
           Map<String, Object> brickMasterIsChibiPresent(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickMaster)this.handler.getDevice()).isChibiPresent();
        result.put("present", value);
        return result;
    }

    public static Map<String, Object> brickMasterIsChibiPresent(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterIsChibiPresent();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Chibi Address")
    public @ActionOutput(name = "address", type="short")
           Map<String, Object> brickMasterGetChibiAddress(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickMaster)this.handler.getDevice()).getChibiAddress();
        result.put("address", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetChibiAddress(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetChibiAddress();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Chibi Master Address")
    public @ActionOutput(name = "address", type="short")
           Map<String, Object> brickMasterGetChibiMasterAddress(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickMaster)this.handler.getDevice()).getChibiMasterAddress();
        result.put("address", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetChibiMasterAddress(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetChibiMasterAddress();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Chibi Slave Address")
    public @ActionOutput(name = "address", type="short")
           Map<String, Object> brickMasterGetChibiSlaveAddress(
            @ActionInput(name = "num") short num) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickMaster)this.handler.getDevice()).getChibiSlaveAddress(num);
        result.put("address", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetChibiSlaveAddress(@Nullable ThingActions actions, short num) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetChibiSlaveAddress(num);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Chibi Signal Strength")
    public @ActionOutput(name = "signalStrength", type="short")
           Map<String, Object> brickMasterGetChibiSignalStrength(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickMaster)this.handler.getDevice()).getChibiSignalStrength();
        result.put("signalStrength", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetChibiSignalStrength(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetChibiSignalStrength();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Chibi Error Log")
    public @ActionOutput(name = "underrun", type="int")
           @ActionOutput(name = "crcError", type="int")
           @ActionOutput(name = "noAck", type="int")
           @ActionOutput(name = "overflow", type="int")
           Map<String, Object> brickMasterGetChibiErrorLog(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.ChibiErrorLog value = ((BrickMaster)this.handler.getDevice()).getChibiErrorLog();
        result.put("underrun", value.underrun);
        result.put("crcError", value.crcError);
        result.put("noAck", value.noAck);
        result.put("overflow", value.overflow);
        return result;
    }

    public static Map<String, Object> brickMasterGetChibiErrorLog(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetChibiErrorLog();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Chibi Frequency")
    public @ActionOutput(name = "frequency", type="short")
           Map<String, Object> brickMasterGetChibiFrequency(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickMaster)this.handler.getDevice()).getChibiFrequency();
        result.put("frequency", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetChibiFrequency(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetChibiFrequency();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Chibi Channel")
    public @ActionOutput(name = "channel", type="short")
           Map<String, Object> brickMasterGetChibiChannel(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickMaster)this.handler.getDevice()).getChibiChannel();
        result.put("channel", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetChibiChannel(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetChibiChannel();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Is RS485 Present")
    public @ActionOutput(name = "present", type="boolean")
           Map<String, Object> brickMasterIsRS485Present(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickMaster)this.handler.getDevice()).isRS485Present();
        result.put("present", value);
        return result;
    }

    public static Map<String, Object> brickMasterIsRS485Present(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterIsRS485Present();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get RS485 Address")
    public @ActionOutput(name = "address", type="short")
           Map<String, Object> brickMasterGetRS485Address(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickMaster)this.handler.getDevice()).getRS485Address();
        result.put("address", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetRS485Address(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetRS485Address();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get RS485 Slave Address")
    public @ActionOutput(name = "address", type="short")
           Map<String, Object> brickMasterGetRS485SlaveAddress(
            @ActionInput(name = "num") short num) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickMaster)this.handler.getDevice()).getRS485SlaveAddress(num);
        result.put("address", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetRS485SlaveAddress(@Nullable ThingActions actions, short num) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetRS485SlaveAddress(num);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get RS485 Error Log")
    public @ActionOutput(name = "crcError", type="int")
           Map<String, Object> brickMasterGetRS485ErrorLog(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickMaster)this.handler.getDevice()).getRS485ErrorLog();
        result.put("crcError", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetRS485ErrorLog(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetRS485ErrorLog();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get RS485 Configuration")
    public @ActionOutput(name = "speed", type="long")
           @ActionOutput(name = "parity", type="char")
           @ActionOutput(name = "stopbits", type="short")
           Map<String, Object> brickMasterGetRS485Configuration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.RS485Configuration value = ((BrickMaster)this.handler.getDevice()).getRS485Configuration();
        result.put("speed", value.speed);
        result.put("parity", value.parity);
        result.put("stopbits", value.stopbits);
        return result;
    }

    public static Map<String, Object> brickMasterGetRS485Configuration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetRS485Configuration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Is Wifi Present")
    public @ActionOutput(name = "present", type="boolean")
           Map<String, Object> brickMasterIsWifiPresent(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickMaster)this.handler.getDevice()).isWifiPresent();
        result.put("present", value);
        return result;
    }

    public static Map<String, Object> brickMasterIsWifiPresent(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterIsWifiPresent();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi Configuration")
    public @ActionOutput(name = "ssid", type="String")
           @ActionOutput(name = "connection", type="short")
           @ActionOutput(name = "ip", type="short[]")
           @ActionOutput(name = "subnetMask", type="short[]")
           @ActionOutput(name = "gateway", type="short[]")
           @ActionOutput(name = "port", type="int")
           Map<String, Object> brickMasterGetWifiConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.WifiConfiguration value = ((BrickMaster)this.handler.getDevice()).getWifiConfiguration();
        result.put("ssid", value.ssid);
        result.put("connection", value.connection);
        result.put("ip", value.ip);
        result.put("subnetMask", value.subnetMask);
        result.put("gateway", value.gateway);
        result.put("port", value.port);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifiConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifiConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi Encryption")
    public @ActionOutput(name = "encryption", type="short")
           @ActionOutput(name = "key", type="String")
           @ActionOutput(name = "keyIndex", type="short")
           @ActionOutput(name = "eapOptions", type="short")
           @ActionOutput(name = "caCertificateLength", type="int")
           @ActionOutput(name = "clientCertificateLength", type="int")
           @ActionOutput(name = "privateKeyLength", type="int")
           Map<String, Object> brickMasterGetWifiEncryption(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.WifiEncryption value = ((BrickMaster)this.handler.getDevice()).getWifiEncryption();
        result.put("encryption", value.encryption);
        result.put("key", value.key);
        result.put("keyIndex", value.keyIndex);
        result.put("eapOptions", value.eapOptions);
        result.put("caCertificateLength", value.caCertificateLength);
        result.put("clientCertificateLength", value.clientCertificateLength);
        result.put("privateKeyLength", value.privateKeyLength);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifiEncryption(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifiEncryption();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi Status")
    public @ActionOutput(name = "macAddress", type="short[]")
           @ActionOutput(name = "bssid", type="short[]")
           @ActionOutput(name = "channel", type="short")
           @ActionOutput(name = "rssi", type="short")
           @ActionOutput(name = "ip", type="short[]")
           @ActionOutput(name = "subnetMask", type="short[]")
           @ActionOutput(name = "gateway", type="short[]")
           @ActionOutput(name = "rxCount", type="long")
           @ActionOutput(name = "txCount", type="long")
           @ActionOutput(name = "state", type="short")
           Map<String, Object> brickMasterGetWifiStatus(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.WifiStatus value = ((BrickMaster)this.handler.getDevice()).getWifiStatus();
        result.put("macAddress", value.macAddress);
        result.put("bssid", value.bssid);
        result.put("channel", value.channel);
        result.put("rssi", value.rssi);
        result.put("ip", value.ip);
        result.put("subnetMask", value.subnetMask);
        result.put("gateway", value.gateway);
        result.put("rxCount", value.rxCount);
        result.put("txCount", value.txCount);
        result.put("state", value.state);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifiStatus(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifiStatus();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Refresh Wifi Status")
    public void brickMasterRefreshWifiStatus(
            ) throws TinkerforgeException {
        ((BrickMaster)this.handler.getDevice()).refreshWifiStatus();
    }

    public static void brickMasterRefreshWifiStatus(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            ((BrickMasterActions) actions).brickMasterRefreshWifiStatus();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi Certificate")
    public @ActionOutput(name = "data", type="short[]")
           @ActionOutput(name = "dataLength", type="short")
           Map<String, Object> brickMasterGetWifiCertificate(
            @ActionInput(name = "index") int index) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.WifiCertificate value = ((BrickMaster)this.handler.getDevice()).getWifiCertificate(index);
        result.put("data", value.data);
        result.put("dataLength", value.dataLength);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifiCertificate(@Nullable ThingActions actions, int index) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifiCertificate(index);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi Power Mode")
    public @ActionOutput(name = "mode", type="short")
           Map<String, Object> brickMasterGetWifiPowerMode(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickMaster)this.handler.getDevice()).getWifiPowerMode();
        result.put("mode", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifiPowerMode(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifiPowerMode();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi Buffer Info")
    public @ActionOutput(name = "overflow", type="long")
           @ActionOutput(name = "lowWatermark", type="int")
           @ActionOutput(name = "used", type="int")
           Map<String, Object> brickMasterGetWifiBufferInfo(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.WifiBufferInfo value = ((BrickMaster)this.handler.getDevice()).getWifiBufferInfo();
        result.put("overflow", value.overflow);
        result.put("lowWatermark", value.lowWatermark);
        result.put("used", value.used);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifiBufferInfo(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifiBufferInfo();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi Regulatory Domain")
    public @ActionOutput(name = "domain", type="short")
           Map<String, Object> brickMasterGetWifiRegulatoryDomain(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickMaster)this.handler.getDevice()).getWifiRegulatoryDomain();
        result.put("domain", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifiRegulatoryDomain(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifiRegulatoryDomain();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Long Wifi Key")
    public @ActionOutput(name = "key", type="String")
           Map<String, Object> brickMasterGetLongWifiKey(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        String value = ((BrickMaster)this.handler.getDevice()).getLongWifiKey();
        result.put("key", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetLongWifiKey(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetLongWifiKey();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi Hostname")
    public @ActionOutput(name = "hostname", type="String")
           Map<String, Object> brickMasterGetWifiHostname(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        String value = ((BrickMaster)this.handler.getDevice()).getWifiHostname();
        result.put("hostname", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifiHostname(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifiHostname();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi Authentication Secret")
    public @ActionOutput(name = "secret", type="String")
           Map<String, Object> brickMasterGetWifiAuthenticationSecret(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        String value = ((BrickMaster)this.handler.getDevice()).getWifiAuthenticationSecret();
        result.put("secret", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifiAuthenticationSecret(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifiAuthenticationSecret();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get USB Voltage")
    public @ActionOutput(name = "voltage", type="int")
           Map<String, Object> brickMasterGetUSBVoltage(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickMaster)this.handler.getDevice()).getUSBVoltage();
        result.put("voltage", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetUSBVoltage(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetUSBVoltage();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Is Ethernet Present")
    public @ActionOutput(name = "present", type="boolean")
           Map<String, Object> brickMasterIsEthernetPresent(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickMaster)this.handler.getDevice()).isEthernetPresent();
        result.put("present", value);
        return result;
    }

    public static Map<String, Object> brickMasterIsEthernetPresent(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterIsEthernetPresent();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Ethernet Configuration")
    public @ActionOutput(name = "connection", type="short")
           @ActionOutput(name = "ip", type="short[]")
           @ActionOutput(name = "subnetMask", type="short[]")
           @ActionOutput(name = "gateway", type="short[]")
           @ActionOutput(name = "port", type="int")
           Map<String, Object> brickMasterGetEthernetConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.EthernetConfiguration value = ((BrickMaster)this.handler.getDevice()).getEthernetConfiguration();
        result.put("connection", value.connection);
        result.put("ip", value.ip);
        result.put("subnetMask", value.subnetMask);
        result.put("gateway", value.gateway);
        result.put("port", value.port);
        return result;
    }

    public static Map<String, Object> brickMasterGetEthernetConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetEthernetConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Ethernet Status")
    public @ActionOutput(name = "macAddress", type="short[]")
           @ActionOutput(name = "ip", type="short[]")
           @ActionOutput(name = "subnetMask", type="short[]")
           @ActionOutput(name = "gateway", type="short[]")
           @ActionOutput(name = "rxCount", type="long")
           @ActionOutput(name = "txCount", type="long")
           @ActionOutput(name = "hostname", type="String")
           Map<String, Object> brickMasterGetEthernetStatus(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.EthernetStatus value = ((BrickMaster)this.handler.getDevice()).getEthernetStatus();
        result.put("macAddress", value.macAddress);
        result.put("ip", value.ip);
        result.put("subnetMask", value.subnetMask);
        result.put("gateway", value.gateway);
        result.put("rxCount", value.rxCount);
        result.put("txCount", value.txCount);
        result.put("hostname", value.hostname);
        return result;
    }

    public static Map<String, Object> brickMasterGetEthernetStatus(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetEthernetStatus();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Ethernet Websocket Configuration")
    public @ActionOutput(name = "sockets", type="short")
           @ActionOutput(name = "port", type="int")
           Map<String, Object> brickMasterGetEthernetWebsocketConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.EthernetWebsocketConfiguration value = ((BrickMaster)this.handler.getDevice()).getEthernetWebsocketConfiguration();
        result.put("sockets", value.sockets);
        result.put("port", value.port);
        return result;
    }

    public static Map<String, Object> brickMasterGetEthernetWebsocketConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetEthernetWebsocketConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Ethernet Authentication Secret")
    public @ActionOutput(name = "secret", type="String")
           Map<String, Object> brickMasterGetEthernetAuthenticationSecret(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        String value = ((BrickMaster)this.handler.getDevice()).getEthernetAuthenticationSecret();
        result.put("secret", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetEthernetAuthenticationSecret(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetEthernetAuthenticationSecret();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Connection Type")
    public @ActionOutput(name = "connectionType", type="short")
           Map<String, Object> brickMasterGetConnectionType(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickMaster)this.handler.getDevice()).getConnectionType();
        result.put("connectionType", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetConnectionType(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetConnectionType();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Is Wifi2 Present")
    public @ActionOutput(name = "present", type="boolean")
           Map<String, Object> brickMasterIsWifi2Present(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickMaster)this.handler.getDevice()).isWifi2Present();
        result.put("present", value);
        return result;
    }

    public static Map<String, Object> brickMasterIsWifi2Present(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterIsWifi2Present();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi2 Authentication Secret")
    public @ActionOutput(name = "secret", type="String")
           Map<String, Object> brickMasterGetWifi2AuthenticationSecret(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        String value = ((BrickMaster)this.handler.getDevice()).getWifi2AuthenticationSecret();
        result.put("secret", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifi2AuthenticationSecret(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifi2AuthenticationSecret();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi2 Configuration")
    public @ActionOutput(name = "port", type="int")
           @ActionOutput(name = "websocketPort", type="int")
           @ActionOutput(name = "websitePort", type="int")
           @ActionOutput(name = "phyMode", type="short")
           @ActionOutput(name = "sleepMode", type="short")
           @ActionOutput(name = "website", type="short")
           Map<String, Object> brickMasterGetWifi2Configuration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.Wifi2Configuration value = ((BrickMaster)this.handler.getDevice()).getWifi2Configuration();
        result.put("port", value.port);
        result.put("websocketPort", value.websocketPort);
        result.put("websitePort", value.websitePort);
        result.put("phyMode", value.phyMode);
        result.put("sleepMode", value.sleepMode);
        result.put("website", value.website);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifi2Configuration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifi2Configuration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi2 Status")
    public @ActionOutput(name = "clientEnabled", type="boolean")
           @ActionOutput(name = "clientStatus", type="short")
           @ActionOutput(name = "clientIP", type="short[]")
           @ActionOutput(name = "clientSubnetMask", type="short[]")
           @ActionOutput(name = "clientGateway", type="short[]")
           @ActionOutput(name = "clientMACAddress", type="short[]")
           @ActionOutput(name = "clientRXCount", type="long")
           @ActionOutput(name = "clientTXCount", type="long")
           @ActionOutput(name = "clientRSSI", type="byte")
           @ActionOutput(name = "apEnabled", type="boolean")
           @ActionOutput(name = "apIP", type="short[]")
           @ActionOutput(name = "apSubnetMask", type="short[]")
           @ActionOutput(name = "apGateway", type="short[]")
           @ActionOutput(name = "apMACAddress", type="short[]")
           @ActionOutput(name = "apRXCount", type="long")
           @ActionOutput(name = "apTXCount", type="long")
           @ActionOutput(name = "apConnectedCount", type="short")
           Map<String, Object> brickMasterGetWifi2Status(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.Wifi2Status value = ((BrickMaster)this.handler.getDevice()).getWifi2Status();
        result.put("clientEnabled", value.clientEnabled);
        result.put("clientStatus", value.clientStatus);
        result.put("clientIP", value.clientIP);
        result.put("clientSubnetMask", value.clientSubnetMask);
        result.put("clientGateway", value.clientGateway);
        result.put("clientMACAddress", value.clientMACAddress);
        result.put("clientRXCount", value.clientRXCount);
        result.put("clientTXCount", value.clientTXCount);
        result.put("clientRSSI", value.clientRSSI);
        result.put("apEnabled", value.apEnabled);
        result.put("apIP", value.apIP);
        result.put("apSubnetMask", value.apSubnetMask);
        result.put("apGateway", value.apGateway);
        result.put("apMACAddress", value.apMACAddress);
        result.put("apRXCount", value.apRXCount);
        result.put("apTXCount", value.apTXCount);
        result.put("apConnectedCount", value.apConnectedCount);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifi2Status(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifi2Status();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi2 Client Configuration")
    public @ActionOutput(name = "enable", type="boolean")
           @ActionOutput(name = "ssid", type="String")
           @ActionOutput(name = "ip", type="short[]")
           @ActionOutput(name = "subnetMask", type="short[]")
           @ActionOutput(name = "gateway", type="short[]")
           @ActionOutput(name = "macAddress", type="short[]")
           @ActionOutput(name = "bssid", type="short[]")
           Map<String, Object> brickMasterGetWifi2ClientConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.Wifi2ClientConfiguration value = ((BrickMaster)this.handler.getDevice()).getWifi2ClientConfiguration();
        result.put("enable", value.enable);
        result.put("ssid", value.ssid);
        result.put("ip", value.ip);
        result.put("subnetMask", value.subnetMask);
        result.put("gateway", value.gateway);
        result.put("macAddress", value.macAddress);
        result.put("bssid", value.bssid);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifi2ClientConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifi2ClientConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi2 Client Hostname")
    public @ActionOutput(name = "hostname", type="String")
           Map<String, Object> brickMasterGetWifi2ClientHostname(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        String value = ((BrickMaster)this.handler.getDevice()).getWifi2ClientHostname();
        result.put("hostname", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifi2ClientHostname(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifi2ClientHostname();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi2 AP Configuration")
    public @ActionOutput(name = "enable", type="boolean")
           @ActionOutput(name = "ssid", type="String")
           @ActionOutput(name = "ip", type="short[]")
           @ActionOutput(name = "subnetMask", type="short[]")
           @ActionOutput(name = "gateway", type="short[]")
           @ActionOutput(name = "encryption", type="short")
           @ActionOutput(name = "hidden", type="boolean")
           @ActionOutput(name = "channel", type="short")
           @ActionOutput(name = "macAddress", type="short[]")
           Map<String, Object> brickMasterGetWifi2APConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.Wifi2APConfiguration value = ((BrickMaster)this.handler.getDevice()).getWifi2APConfiguration();
        result.put("enable", value.enable);
        result.put("ssid", value.ssid);
        result.put("ip", value.ip);
        result.put("subnetMask", value.subnetMask);
        result.put("gateway", value.gateway);
        result.put("encryption", value.encryption);
        result.put("hidden", value.hidden);
        result.put("channel", value.channel);
        result.put("macAddress", value.macAddress);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifi2APConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifi2APConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi2 Firmware Version")
    public @ActionOutput(name = "firmwareVersion", type="short[]")
           Map<String, Object> brickMasterGetWifi2FirmwareVersion(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short[] value = ((BrickMaster)this.handler.getDevice()).getWifi2FirmwareVersion();
        result.put("firmwareVersion", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifi2FirmwareVersion(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifi2FirmwareVersion();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Enable Wifi2 Status LED")
    public void brickMasterEnableWifi2StatusLED(
            ) throws TinkerforgeException {
        ((BrickMaster)this.handler.getDevice()).enableWifi2StatusLED();
    }

    public static void brickMasterEnableWifi2StatusLED(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            ((BrickMasterActions) actions).brickMasterEnableWifi2StatusLED();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Disable Wifi2 Status LED")
    public void brickMasterDisableWifi2StatusLED(
            ) throws TinkerforgeException {
        ((BrickMaster)this.handler.getDevice()).disableWifi2StatusLED();
    }

    public static void brickMasterDisableWifi2StatusLED(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            ((BrickMasterActions) actions).brickMasterDisableWifi2StatusLED();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Is Wifi2 Status LED Enabled")
    public @ActionOutput(name = "enabled", type="boolean")
           Map<String, Object> brickMasterIsWifi2StatusLEDEnabled(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickMaster)this.handler.getDevice()).isWifi2StatusLEDEnabled();
        result.put("enabled", value);
        return result;
    }

    public static Map<String, Object> brickMasterIsWifi2StatusLEDEnabled(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterIsWifi2StatusLEDEnabled();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi2 Mesh Configuration")
    public @ActionOutput(name = "enable", type="boolean")
           @ActionOutput(name = "rootIP", type="short[]")
           @ActionOutput(name = "rootSubnetMask", type="short[]")
           @ActionOutput(name = "rootGateway", type="short[]")
           @ActionOutput(name = "routerBSSID", type="short[]")
           @ActionOutput(name = "groupID", type="short[]")
           @ActionOutput(name = "groupSSIDPrefix", type="String")
           @ActionOutput(name = "gatewayIP", type="short[]")
           @ActionOutput(name = "gatewayPort", type="int")
           Map<String, Object> brickMasterGetWifi2MeshConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.Wifi2MeshConfiguration value = ((BrickMaster)this.handler.getDevice()).getWifi2MeshConfiguration();
        result.put("enable", value.enable);
        result.put("rootIP", value.rootIP);
        result.put("rootSubnetMask", value.rootSubnetMask);
        result.put("rootGateway", value.rootGateway);
        result.put("routerBSSID", value.routerBSSID);
        result.put("groupID", value.groupID);
        result.put("groupSSIDPrefix", value.groupSSIDPrefix);
        result.put("gatewayIP", value.gatewayIP);
        result.put("gatewayPort", value.gatewayPort);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifi2MeshConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifi2MeshConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi2 Mesh Router SSID")
    public @ActionOutput(name = "ssid", type="String")
           Map<String, Object> brickMasterGetWifi2MeshRouterSSID(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        String value = ((BrickMaster)this.handler.getDevice()).getWifi2MeshRouterSSID();
        result.put("ssid", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifi2MeshRouterSSID(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifi2MeshRouterSSID();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi2 Mesh Common Status")
    public @ActionOutput(name = "status", type="short")
           @ActionOutput(name = "rootNode", type="boolean")
           @ActionOutput(name = "rootCandidate", type="boolean")
           @ActionOutput(name = "connectedNodes", type="int")
           @ActionOutput(name = "rxCount", type="long")
           @ActionOutput(name = "txCount", type="long")
           Map<String, Object> brickMasterGetWifi2MeshCommonStatus(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.Wifi2MeshCommonStatus value = ((BrickMaster)this.handler.getDevice()).getWifi2MeshCommonStatus();
        result.put("status", value.status);
        result.put("rootNode", value.rootNode);
        result.put("rootCandidate", value.rootCandidate);
        result.put("connectedNodes", value.connectedNodes);
        result.put("rxCount", value.rxCount);
        result.put("txCount", value.txCount);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifi2MeshCommonStatus(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifi2MeshCommonStatus();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi2 Mesh Client Status")
    public @ActionOutput(name = "hostname", type="String")
           @ActionOutput(name = "ip", type="short[]")
           @ActionOutput(name = "subnetMask", type="short[]")
           @ActionOutput(name = "gateway", type="short[]")
           @ActionOutput(name = "macAddress", type="short[]")
           Map<String, Object> brickMasterGetWifi2MeshClientStatus(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.Wifi2MeshClientStatus value = ((BrickMaster)this.handler.getDevice()).getWifi2MeshClientStatus();
        result.put("hostname", value.hostname);
        result.put("ip", value.ip);
        result.put("subnetMask", value.subnetMask);
        result.put("gateway", value.gateway);
        result.put("macAddress", value.macAddress);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifi2MeshClientStatus(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifi2MeshClientStatus();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Wifi2 Mesh AP Status")
    public @ActionOutput(name = "ssid", type="String")
           @ActionOutput(name = "ip", type="short[]")
           @ActionOutput(name = "subnetMask", type="short[]")
           @ActionOutput(name = "gateway", type="short[]")
           @ActionOutput(name = "macAddress", type="short[]")
           Map<String, Object> brickMasterGetWifi2MeshAPStatus(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.Wifi2MeshAPStatus value = ((BrickMaster)this.handler.getDevice()).getWifi2MeshAPStatus();
        result.put("ssid", value.ssid);
        result.put("ip", value.ip);
        result.put("subnetMask", value.subnetMask);
        result.put("gateway", value.gateway);
        result.put("macAddress", value.macAddress);
        return result;
    }

    public static Map<String, Object> brickMasterGetWifi2MeshAPStatus(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetWifi2MeshAPStatus();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Identity")
    public @ActionOutput(name = "uid", type="String")
           @ActionOutput(name = "connectedUid", type="String")
           @ActionOutput(name = "position", type="char")
           @ActionOutput(name = "hardwareVersion", type="short[]")
           @ActionOutput(name = "firmwareVersion", type="short[]")
           @ActionOutput(name = "deviceIdentifier", type="int")
           Map<String, Object> brickMasterGetIdentity(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.Identity value = ((BrickMaster)this.handler.getDevice()).getIdentity();
        result.put("uid", value.uid);
        result.put("connectedUid", value.connectedUid);
        result.put("position", value.position);
        result.put("hardwareVersion", value.hardwareVersion);
        result.put("firmwareVersion", value.firmwareVersion);
        result.put("deviceIdentifier", value.deviceIdentifier);
        return result;
    }

    public static Map<String, Object> brickMasterGetIdentity(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetIdentity();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Is Status LED Enabled")
    public @ActionOutput(name = "enabled", type="boolean")
           Map<String, Object> brickMasterIsStatusLEDEnabled(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickMaster)this.handler.getDevice()).isStatusLEDEnabled();
        result.put("enabled", value);
        return result;
    }

    public static Map<String, Object> brickMasterIsStatusLEDEnabled(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterIsStatusLEDEnabled();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Chip Temperature")
    public @ActionOutput(name = "temperature", type="short")
           Map<String, Object> brickMasterGetChipTemperature(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickMaster)this.handler.getDevice()).getChipTemperature();
        result.put("temperature", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetChipTemperature(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetChipTemperature();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get Send Timeout Count")
    public @ActionOutput(name = "timeoutCount", type="long")
           Map<String, Object> brickMasterGetSendTimeoutCount(
            @ActionInput(name = "communicationMethod") short communicationMethod) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        long value = ((BrickMaster)this.handler.getDevice()).getSendTimeoutCount(communicationMethod);
        result.put("timeoutCount", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetSendTimeoutCount(@Nullable ThingActions actions, short communicationMethod) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetSendTimeoutCount(communicationMethod);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get SPITFP Baudrate Config")
    public @ActionOutput(name = "enableDynamicBaudrate", type="boolean")
           @ActionOutput(name = "minimumDynamicBaudrate", type="long")
           Map<String, Object> brickMasterGetSPITFPBaudrateConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.SPITFPBaudrateConfig value = ((BrickMaster)this.handler.getDevice()).getSPITFPBaudrateConfig();
        result.put("enableDynamicBaudrate", value.enableDynamicBaudrate);
        result.put("minimumDynamicBaudrate", value.minimumDynamicBaudrate);
        return result;
    }

    public static Map<String, Object> brickMasterGetSPITFPBaudrateConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetSPITFPBaudrateConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get SPITFP Error Count")
    public @ActionOutput(name = "errorCountACKChecksum", type="long")
           @ActionOutput(name = "errorCountMessageChecksum", type="long")
           @ActionOutput(name = "errorCountFrame", type="long")
           @ActionOutput(name = "errorCountOverflow", type="long")
           Map<String, Object> brickMasterGetSPITFPErrorCount(
            @ActionInput(name = "brickletPort") char brickletPort) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickMaster.SPITFPErrorCount value = ((BrickMaster)this.handler.getDevice()).getSPITFPErrorCount(brickletPort);
        result.put("errorCountACKChecksum", value.errorCountACKChecksum);
        result.put("errorCountMessageChecksum", value.errorCountMessageChecksum);
        result.put("errorCountFrame", value.errorCountFrame);
        result.put("errorCountOverflow", value.errorCountOverflow);
        return result;
    }

    public static Map<String, Object> brickMasterGetSPITFPErrorCount(@Nullable ThingActions actions, char brickletPort) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetSPITFPErrorCount(brickletPort);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }

    @RuleAction(label = "Get SPITFP Baudrate")
    public @ActionOutput(name = "baudrate", type="long")
           Map<String, Object> brickMasterGetSPITFPBaudrate(
            @ActionInput(name = "brickletPort") char brickletPort) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        long value = ((BrickMaster)this.handler.getDevice()).getSPITFPBaudrate(brickletPort);
        result.put("baudrate", value);
        return result;
    }

    public static Map<String, Object> brickMasterGetSPITFPBaudrate(@Nullable ThingActions actions, char brickletPort) throws TinkerforgeException {
        if (actions instanceof BrickMasterActions) {
            return ((BrickMasterActions) actions).brickMasterGetSPITFPBaudrate(brickletPort);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickMasterActions class.");
        }
    }
}
