package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletAmbientLightV2Actions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Illuminance")
    public @ActionOutput(name = "illuminance", type="long")
           Map<String, Object> brickletAmbientLightV2GetIlluminance(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        long value = ((BrickletAmbientLightV2)this.handler.getDevice()).getIlluminance();
        result.put("illuminance", value);
        return result;
    }

    public static Map<String, Object> brickletAmbientLightV2GetIlluminance(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAmbientLightV2Actions) {
            return ((BrickletAmbientLightV2Actions) actions).brickletAmbientLightV2GetIlluminance();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAmbientLightV2Actions class.");
        }
    }

    @RuleAction(label = "Get Configuration")
    public @ActionOutput(name = "illuminanceRange", type="short")
           @ActionOutput(name = "integrationTime", type="short")
           Map<String, Object> brickletAmbientLightV2GetConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletAmbientLightV2.Configuration value = ((BrickletAmbientLightV2)this.handler.getDevice()).getConfiguration();
        result.put("illuminanceRange", value.illuminanceRange);
        result.put("integrationTime", value.integrationTime);
        return result;
    }

    public static Map<String, Object> brickletAmbientLightV2GetConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAmbientLightV2Actions) {
            return ((BrickletAmbientLightV2Actions) actions).brickletAmbientLightV2GetConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAmbientLightV2Actions class.");
        }
    }

    @RuleAction(label = "Get Identity")
    public @ActionOutput(name = "uid", type="String")
           @ActionOutput(name = "connectedUid", type="String")
           @ActionOutput(name = "position", type="char")
           @ActionOutput(name = "hardwareVersion", type="short[]")
           @ActionOutput(name = "firmwareVersion", type="short[]")
           @ActionOutput(name = "deviceIdentifier", type="int")
           Map<String, Object> brickletAmbientLightV2GetIdentity(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletAmbientLightV2.Identity value = ((BrickletAmbientLightV2)this.handler.getDevice()).getIdentity();
        result.put("uid", value.uid);
        result.put("connectedUid", value.connectedUid);
        result.put("position", value.position);
        result.put("hardwareVersion", value.hardwareVersion);
        result.put("firmwareVersion", value.firmwareVersion);
        result.put("deviceIdentifier", value.deviceIdentifier);
        return result;
    }

    public static Map<String, Object> brickletAmbientLightV2GetIdentity(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAmbientLightV2Actions) {
            return ((BrickletAmbientLightV2Actions) actions).brickletAmbientLightV2GetIdentity();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAmbientLightV2Actions class.");
        }
    }
}
