package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletCompassActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Heading")
    public @ActionOutput(name = "heading", type="int")
           Map<String, Object> brickletCompassGetHeading(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletCompass)this.handler.getDevice()).getHeading();
        result.put("heading", value);
        return result;
    }

    public static Map<String, Object> brickletCompassGetHeading(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletCompassActions) {
            return ((BrickletCompassActions) actions).brickletCompassGetHeading();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletCompassActions class.");
        }
    }

    @RuleAction(label = "Get Magnetic Flux Density")
    public @ActionOutput(name = "x", type="int")
           @ActionOutput(name = "y", type="int")
           @ActionOutput(name = "z", type="int")
           Map<String, Object> brickletCompassGetMagneticFluxDensity(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletCompass.MagneticFluxDensity value = ((BrickletCompass)this.handler.getDevice()).getMagneticFluxDensity();
        result.put("x", value.x);
        result.put("y", value.y);
        result.put("z", value.z);
        return result;
    }

    public static Map<String, Object> brickletCompassGetMagneticFluxDensity(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletCompassActions) {
            return ((BrickletCompassActions) actions).brickletCompassGetMagneticFluxDensity();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletCompassActions class.");
        }
    }

    @RuleAction(label = "Get Configuration")
    public @ActionOutput(name = "dataRate", type="int")
           @ActionOutput(name = "backgroundCalibration", type="boolean")
           Map<String, Object> brickletCompassGetConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletCompass.Configuration value = ((BrickletCompass)this.handler.getDevice()).getConfiguration();
        result.put("dataRate", value.dataRate);
        result.put("backgroundCalibration", value.backgroundCalibration);
        return result;
    }

    public static Map<String, Object> brickletCompassGetConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletCompassActions) {
            return ((BrickletCompassActions) actions).brickletCompassGetConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletCompassActions class.");
        }
    }

    @RuleAction(label = "Get Calibration")
    public @ActionOutput(name = "offset", type="int[]")
           @ActionOutput(name = "gain", type="int[]")
           Map<String, Object> brickletCompassGetCalibration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletCompass.Calibration value = ((BrickletCompass)this.handler.getDevice()).getCalibration();
        result.put("offset", value.offset);
        result.put("gain", value.gain);
        return result;
    }

    public static Map<String, Object> brickletCompassGetCalibration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletCompassActions) {
            return ((BrickletCompassActions) actions).brickletCompassGetCalibration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletCompassActions class.");
        }
    }

    @RuleAction(label = "Read UID")
    public @ActionOutput(name = "uid", type="long")
           Map<String, Object> brickletCompassReadUID(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        long value = ((BrickletCompass)this.handler.getDevice()).readUID();
        result.put("uid", value);
        return result;
    }

    public static Map<String, Object> brickletCompassReadUID(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletCompassActions) {
            return ((BrickletCompassActions) actions).brickletCompassReadUID();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletCompassActions class.");
        }
    }

    @RuleAction(label = "Get Chip Temperature")
    public @ActionOutput(name = "temperature", type="int")
           Map<String, Object> brickletCompassGetChipTemperature(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletCompass)this.handler.getDevice()).getChipTemperature();
        result.put("temperature", value);
        return result;
    }

    public static Map<String, Object> brickletCompassGetChipTemperature(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletCompassActions) {
            return ((BrickletCompassActions) actions).brickletCompassGetChipTemperature();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletCompassActions class.");
        }
    }

    @RuleAction(label = "Get Status LED Config")
    public @ActionOutput(name = "config", type="int")
           Map<String, Object> brickletCompassGetStatusLEDConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletCompass)this.handler.getDevice()).getStatusLEDConfig();
        result.put("config", value);
        return result;
    }

    public static Map<String, Object> brickletCompassGetStatusLEDConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletCompassActions) {
            return ((BrickletCompassActions) actions).brickletCompassGetStatusLEDConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletCompassActions class.");
        }
    }

    @RuleAction(label = "Get Bootloader Mode")
    public @ActionOutput(name = "mode", type="int")
           Map<String, Object> brickletCompassGetBootloaderMode(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletCompass)this.handler.getDevice()).getBootloaderMode();
        result.put("mode", value);
        return result;
    }

    public static Map<String, Object> brickletCompassGetBootloaderMode(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletCompassActions) {
            return ((BrickletCompassActions) actions).brickletCompassGetBootloaderMode();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletCompassActions class.");
        }
    }

    @RuleAction(label = "Get SPITFP Error Count")
    public @ActionOutput(name = "errorCountAckChecksum", type="long")
           @ActionOutput(name = "errorCountMessageChecksum", type="long")
           @ActionOutput(name = "errorCountFrame", type="long")
           @ActionOutput(name = "errorCountOverflow", type="long")
           Map<String, Object> brickletCompassGetSPITFPErrorCount(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletCompass.SPITFPErrorCount value = ((BrickletCompass)this.handler.getDevice()).getSPITFPErrorCount();
        result.put("errorCountAckChecksum", value.errorCountAckChecksum);
        result.put("errorCountMessageChecksum", value.errorCountMessageChecksum);
        result.put("errorCountFrame", value.errorCountFrame);
        result.put("errorCountOverflow", value.errorCountOverflow);
        return result;
    }

    public static Map<String, Object> brickletCompassGetSPITFPErrorCount(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletCompassActions) {
            return ((BrickletCompassActions) actions).brickletCompassGetSPITFPErrorCount();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletCompassActions class.");
        }
    }

    @RuleAction(label = "Get Identity")
    public @ActionOutput(name = "uid", type="String")
           @ActionOutput(name = "connectedUid", type="String")
           @ActionOutput(name = "position", type="char")
           @ActionOutput(name = "hardwareVersion", type="int[]")
           @ActionOutput(name = "firmwareVersion", type="int[]")
           @ActionOutput(name = "deviceIdentifier", type="int")
           Map<String, Object> brickletCompassGetIdentity(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletCompass.Identity value = ((BrickletCompass)this.handler.getDevice()).getIdentity();
        result.put("uid", value.uid);
        result.put("connectedUid", value.connectedUid);
        result.put("position", value.position);
        result.put("hardwareVersion", value.hardwareVersion);
        result.put("firmwareVersion", value.firmwareVersion);
        result.put("deviceIdentifier", value.deviceIdentifier);
        return result;
    }

    public static Map<String, Object> brickletCompassGetIdentity(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletCompassActions) {
            return ((BrickletCompassActions) actions).brickletCompassGetIdentity();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletCompassActions class.");
        }
    }
}
