package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletThermalImagingActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get High Contrast Image")
    public @ActionOutput(name = "image", type="int[]")
           Map<String, Object> brickletThermalImagingGetHighContrastImage(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int[] value = ((BrickletThermalImaging)this.handler.getDevice()).getHighContrastImage();
        result.put("image", value);
        return result;
    }

    public static Map<String, Object> brickletThermalImagingGetHighContrastImage(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletThermalImagingActions) {
            return ((BrickletThermalImagingActions) actions).brickletThermalImagingGetHighContrastImage();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletThermalImagingActions class.");
        }
    }

    @RuleAction(label = "Get Temperature Image")
    public @ActionOutput(name = "image", type="int[]")
           Map<String, Object> brickletThermalImagingGetTemperatureImage(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int[] value = ((BrickletThermalImaging)this.handler.getDevice()).getTemperatureImage();
        result.put("image", value);
        return result;
    }

    public static Map<String, Object> brickletThermalImagingGetTemperatureImage(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletThermalImagingActions) {
            return ((BrickletThermalImagingActions) actions).brickletThermalImagingGetTemperatureImage();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletThermalImagingActions class.");
        }
    }

    @RuleAction(label = "Get Statistics")
    public @ActionOutput(name = "spotmeterStatistics", type="int[]")
           @ActionOutput(name = "temperatures", type="int[]")
           @ActionOutput(name = "resolution", type="int")
           @ActionOutput(name = "ffcStatus", type="int")
           @ActionOutput(name = "temperatureWarning", type="boolean[]")
           Map<String, Object> brickletThermalImagingGetStatistics(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletThermalImaging.Statistics value = ((BrickletThermalImaging)this.handler.getDevice()).getStatistics();
        result.put("spotmeterStatistics", value.spotmeterStatistics);
        result.put("temperatures", value.temperatures);
        result.put("resolution", value.resolution);
        result.put("ffcStatus", value.ffcStatus);
        result.put("temperatureWarning", value.temperatureWarning);
        return result;
    }

    public static Map<String, Object> brickletThermalImagingGetStatistics(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletThermalImagingActions) {
            return ((BrickletThermalImagingActions) actions).brickletThermalImagingGetStatistics();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletThermalImagingActions class.");
        }
    }

    @RuleAction(label = "Get Resolution")
    public @ActionOutput(name = "resolution", type="int")
           Map<String, Object> brickletThermalImagingGetResolution(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletThermalImaging)this.handler.getDevice()).getResolution();
        result.put("resolution", value);
        return result;
    }

    public static Map<String, Object> brickletThermalImagingGetResolution(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletThermalImagingActions) {
            return ((BrickletThermalImagingActions) actions).brickletThermalImagingGetResolution();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletThermalImagingActions class.");
        }
    }

    @RuleAction(label = "Get Spotmeter Config")
    public @ActionOutput(name = "regionOfInterest", type="int[]")
           Map<String, Object> brickletThermalImagingGetSpotmeterConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int[] value = ((BrickletThermalImaging)this.handler.getDevice()).getSpotmeterConfig();
        result.put("regionOfInterest", value);
        return result;
    }

    public static Map<String, Object> brickletThermalImagingGetSpotmeterConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletThermalImagingActions) {
            return ((BrickletThermalImagingActions) actions).brickletThermalImagingGetSpotmeterConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletThermalImagingActions class.");
        }
    }

    @RuleAction(label = "Get High Contrast Config")
    public @ActionOutput(name = "regionOfInterest", type="int[]")
           @ActionOutput(name = "dampeningFactor", type="int")
           @ActionOutput(name = "clipLimit", type="int[]")
           @ActionOutput(name = "emptyCounts", type="int")
           Map<String, Object> brickletThermalImagingGetHighContrastConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletThermalImaging.HighContrastConfig value = ((BrickletThermalImaging)this.handler.getDevice()).getHighContrastConfig();
        result.put("regionOfInterest", value.regionOfInterest);
        result.put("dampeningFactor", value.dampeningFactor);
        result.put("clipLimit", value.clipLimit);
        result.put("emptyCounts", value.emptyCounts);
        return result;
    }

    public static Map<String, Object> brickletThermalImagingGetHighContrastConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletThermalImagingActions) {
            return ((BrickletThermalImagingActions) actions).brickletThermalImagingGetHighContrastConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletThermalImagingActions class.");
        }
    }

    @RuleAction(label = "Read UID")
    public @ActionOutput(name = "uid", type="long")
           Map<String, Object> brickletThermalImagingReadUID(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        long value = ((BrickletThermalImaging)this.handler.getDevice()).readUID();
        result.put("uid", value);
        return result;
    }

    public static Map<String, Object> brickletThermalImagingReadUID(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletThermalImagingActions) {
            return ((BrickletThermalImagingActions) actions).brickletThermalImagingReadUID();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletThermalImagingActions class.");
        }
    }

    @RuleAction(label = "Get Chip Temperature")
    public @ActionOutput(name = "temperature", type="int")
           Map<String, Object> brickletThermalImagingGetChipTemperature(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletThermalImaging)this.handler.getDevice()).getChipTemperature();
        result.put("temperature", value);
        return result;
    }

    public static Map<String, Object> brickletThermalImagingGetChipTemperature(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletThermalImagingActions) {
            return ((BrickletThermalImagingActions) actions).brickletThermalImagingGetChipTemperature();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletThermalImagingActions class.");
        }
    }

    @RuleAction(label = "Get Status LED Config")
    public @ActionOutput(name = "config", type="int")
           Map<String, Object> brickletThermalImagingGetStatusLEDConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletThermalImaging)this.handler.getDevice()).getStatusLEDConfig();
        result.put("config", value);
        return result;
    }

    public static Map<String, Object> brickletThermalImagingGetStatusLEDConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletThermalImagingActions) {
            return ((BrickletThermalImagingActions) actions).brickletThermalImagingGetStatusLEDConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletThermalImagingActions class.");
        }
    }

    @RuleAction(label = "Get Bootloader Mode")
    public @ActionOutput(name = "mode", type="int")
           Map<String, Object> brickletThermalImagingGetBootloaderMode(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletThermalImaging)this.handler.getDevice()).getBootloaderMode();
        result.put("mode", value);
        return result;
    }

    public static Map<String, Object> brickletThermalImagingGetBootloaderMode(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletThermalImagingActions) {
            return ((BrickletThermalImagingActions) actions).brickletThermalImagingGetBootloaderMode();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletThermalImagingActions class.");
        }
    }

    @RuleAction(label = "Get SPITFP Error Count")
    public @ActionOutput(name = "errorCountAckChecksum", type="long")
           @ActionOutput(name = "errorCountMessageChecksum", type="long")
           @ActionOutput(name = "errorCountFrame", type="long")
           @ActionOutput(name = "errorCountOverflow", type="long")
           Map<String, Object> brickletThermalImagingGetSPITFPErrorCount(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletThermalImaging.SPITFPErrorCount value = ((BrickletThermalImaging)this.handler.getDevice()).getSPITFPErrorCount();
        result.put("errorCountAckChecksum", value.errorCountAckChecksum);
        result.put("errorCountMessageChecksum", value.errorCountMessageChecksum);
        result.put("errorCountFrame", value.errorCountFrame);
        result.put("errorCountOverflow", value.errorCountOverflow);
        return result;
    }

    public static Map<String, Object> brickletThermalImagingGetSPITFPErrorCount(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletThermalImagingActions) {
            return ((BrickletThermalImagingActions) actions).brickletThermalImagingGetSPITFPErrorCount();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletThermalImagingActions class.");
        }
    }

    @RuleAction(label = "Get Identity")
    public @ActionOutput(name = "uid", type="String")
           @ActionOutput(name = "connectedUid", type="String")
           @ActionOutput(name = "position", type="char")
           @ActionOutput(name = "hardwareVersion", type="int[]")
           @ActionOutput(name = "firmwareVersion", type="int[]")
           @ActionOutput(name = "deviceIdentifier", type="int")
           Map<String, Object> brickletThermalImagingGetIdentity(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletThermalImaging.Identity value = ((BrickletThermalImaging)this.handler.getDevice()).getIdentity();
        result.put("uid", value.uid);
        result.put("connectedUid", value.connectedUid);
        result.put("position", value.position);
        result.put("hardwareVersion", value.hardwareVersion);
        result.put("firmwareVersion", value.firmwareVersion);
        result.put("deviceIdentifier", value.deviceIdentifier);
        return result;
    }

    public static Map<String, Object> brickletThermalImagingGetIdentity(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletThermalImagingActions) {
            return ((BrickletThermalImagingActions) actions).brickletThermalImagingGetIdentity();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletThermalImagingActions class.");
        }
    }
}
